# Nuclia CLI/SDK

This Nuclia SDK/CLI is designed to facilitate use of the Nuclia API.

There are two developer experiences:

- CLI: by using the cli `nuclia` you can interact with Nuclia via command line
- SDK: allows to write simple Python scripts to interact with Nuclia

## Installation

It requires Python (≥3.8) and can be installed with:

```sh
pip install nuclia
```

## Upgrades

To know your current version:

```sh
pip show nuclia
```

To upgrade to the latest version:

```sh
pip install nuclia --upgrade
```

## Usage

- [Authentication](02-auth.md)
- [Access a Knowledge Box](03-kb.md)
- [Upload contents](04-upload.md)
- [Search and answer generation](05-search.md)
- [Read extracted data](06-read.md)
- [Work with a NUA key](07-nua.md)
- [Import/export a Knowledge Box](08-import-export.md)
- [Backup a Knowledge Box](09-kb-backup.md)
- [Manage Knowledge Box configuration & labels](10-manage.md)
- [Query & download activity logs](11-activity-log.md)
- [Agents: Automate Tasks for Better Search Performance](12-da-agents.md)
- [AI Agents](13-ai-agents.md)
